# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .....schema_classes import DataHubIngestionSourceConfigClass
from .....schema_classes import DataHubIngestionSourceInfoClass
from .....schema_classes import DataHubIngestionSourceScheduleClass
from .....schema_classes import DataHubIngestionSourceSourceClass
from .....schema_classes import DataHubIngestionSourceSourceTypeClass


DataHubIngestionSourceConfig = DataHubIngestionSourceConfigClass
DataHubIngestionSourceInfo = DataHubIngestionSourceInfoClass
DataHubIngestionSourceSchedule = DataHubIngestionSourceScheduleClass
DataHubIngestionSourceSource = DataHubIngestionSourceSourceClass
DataHubIngestionSourceSourceType = DataHubIngestionSourceSourceTypeClass

# fmt: on
